@@ -26,6 +26,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <strings.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -34,6 +35,8 @@
 #include <sys/mman.h>
 
 #include "util.h"
+#include "strv.h"
+#include "utf8.h"
 #include "string.h"
 #include "queue.h"
 #include "settings.h"
@@ -466,6 +469,12 @@ LIB_EXPORT bool l_settings_load_from_file(struct l_settings *settings,
 		return false;
 	}
 
+	/* Nothing to do, assume success */
+	if (st.st_size == 0) {
+		close(fd);
+		return true;
+	}
+
 	data = mmap(NULL, st.st_size, PROT_READ, MAP_SHARED, fd, 0);
 	if (data == MAP_FAILED) {
 		l_util_debug(settings->debug_handler, settings->debug_data,
